#' 96 Well Plate Example Layout
#'
#' 96 well plate map in a wide format used in the lab. Contains information of actual Sample ID names in each well.
#'
#' This file is stored in inst/extdata
#'
#' @format A data frame with 9 rows and 13 variables.
#' \describe{
#'   \item{Plate}{Contains rows labelled "A" to "H"}
#'   \item{1-12}{Contains columns labelled "1" to "12"}
#' }
#' @name example_platelayout_1_xlsx
NULL

#' 5-Point Standard Curve Example Plate Layout
#'
#' 96 well plate map in a wide format used in the lab, used for when 5-point standard curves are required for pk/pf/pv analysis. Contains information of actual Sample ID names in each well.
#'
#' This file is stored in inst/extdata
#'
#' @format A data frame with 9 rows and 13 variables.
#' \describe{
#'   \item{Plate}{Contains rows labelled "A" to "H"}
#'   \item{1-12}{Contains columns labelled "1" to "12"}
#' }
#' @name example_platelayout_pk_5std_xlsx
NULL

#' 10-Point Standard Curve Example Plate Layout
#'
#' 96 well plate map in a wide format used in the lab, used for when 10-point standard curves are required for pk/pf/pv analysis. Contains information of actual Sample ID names in each well.
#'
#' This file is stored in inst/extdata
#'
#' @format A data frame with 9 rows and 13 variables.
#' \describe{
#'   \item{Plate}{Contains rows labelled "A" to "H"}
#'   \item{1-12}{Contains columns labelled "1" to "12"}
#' }
#' @name example_platelayout_pk_10std_xlsx
NULL

#' Example Serological Dataset: Bioplex Plate 1
#'
#' A dataset containing raw MFI values and metadata from a sample plate run (Bioplex).
#'
#' This file is stored in inst/extdata
#'
#' @format A data frame with 103 rows and 15 columns.
#' @source Randomised data
#' @name example_BioPlex_plate1_xlsx
NULL

#' Example Serological Dataset: Bioplex Plate 2
#'
#' A dataset containing raw MFI values and metadata from a sample plate run (Bioplex).
#'
#' @format A data frame with 103 rows and 15 columns.
#' @source Randomised data
#' @name example_BioPlex_plate2_xlsx
NULL

#' Example Serological Dataset: Bioplex Plate 3
#'
#' A dataset containing raw MFI values and metadata from a sample plate run (Bioplex).
#'
#' This file is stored in inst/extdata
#'
#' @format A data frame with 104 rows and 8 columns.
#' @source Randomised data
#' @name example_BioPlex_plate3_xlsx
NULL

#' Example Serological Dataset: Bioplex PvLDH Plate 1
#'
#' A dataset containing raw MFI values and metadata from a sample plate run (Bioplex).
#'
#' This file is stored in inst/extdata
#'
#' @format A data frame with 103 rows and 15 columns.
#' @source Randomised data
#' @name example_BioPlex_PvLDH_plate1_xlsx
NULL

#' Example Serological Dataset: MAGPIX Plate 1

#' A dataset containing raw MFI values and metadata from a sample plate run (MAGPIX).
#'
#' This file is stored in inst/extdata
#'
#' @format A data frame with 614 rows and 17 columns.
#' @source Randomised data
#' @name example_MAGPIX_plate1_csv
NULL

#' Example Serological Dataset: MAGPIX Plate 2
#'
#' A dataset containing raw MFI values and metadata from a sample plate run (MAGPIX).
#'
#' This file is stored in inst/extdata
#'
#' @format A data frame with 614 rows and 17 columns.
#' @source Randomised data
#' @name example_MAGPIX_plate2_csv
NULL

#' Example Serological Dataset: MAGPIX Plate 3
#'
#' A dataset containing raw MFI values and metadata from a sample plate run (MAGPIX).
#'
#' This file is stored in inst/extdata
#'
#' @format A data frame with 614 rows and 17 columns.
#' @source Randomised data
#' @name example_MAGPIX_plate3_csv
NULL

#' Example Serological Dataset: MAGPIX Plate 1 Pk Analysis 5-Point Standard Curve

#' A dataset containing raw MFI values and metadata from a sample plate run (MAGPIX).
#'
#' This file is stored in inst/extdata
#'
#' @format A data frame with 614 rows and 17 columns.
#' @source Randomised data
#' @name example_MAGPIX_pk_5std_plate1_csv
NULL

#' Example Serological Dataset: MAGPIX Plate 2 Pk Analysis 5-Point Standard Curve
#'
#' A dataset containing raw MFI values and metadata from a sample plate run (MAGPIX).
#'
#' This file is stored in inst/extdata
#'
#' @format A data frame with 614 rows and 17 columns.
#' @source Randomised data
#' @name example_MAGPIX_pk_5std_plate2_csv
NULL

#' Example Serological Dataset: MAGPIX Plate 1 Pk Analysis 10-Point Standard Curve

#' A dataset containing raw MFI values and metadata from a sample plate run (MAGPIX).
#'
#' This file is stored in inst/extdata
#'
#' @format A data frame with 614 rows and 17 columns.
#' @source Randomised data
#' @name example_MAGPIX_pk_10std_plate1_csv
NULL

#' Example Serological Dataset: MAGPIX Plate 2 Pk Analysis 10-Point Standard Curve
#'
#' A dataset containing raw MFI values and metadata from a sample plate run (MAGPIX).
#'
#' This file is stored in inst/extdata
#'
#' @format A data frame with 614 rows and 17 columns.
#' @source Randomised data
#' @name example_MAGPIX_pk_10std_plate2_csv
NULL
