utils::globalVariables(c(
  ".", ".pred_new", "1", "12",
  "Antigen", "Antigens", "Beads", "Col", "Content", "Count", "df",
  "Dilution", "Location", "Location.2", "MFI", "Plate", "Program",
  "QC_total", "RAU", "RAU_Method", "Repeat", "Row", "Run", "Sample",
  "SampleID", "Sens_Spec", "Species", "Sum", "Text", "Type", "Warning",
  "antigen", "asym_par", "content", "data_type", "delete", "dilution",
  "div", "ed50", "error", "eth_fit", "fct_rev", "file_name", "fromJSON",
  "glue", "log_mfi", "log.std", "low_asym", "max_dil", "max_s1", "mfi",
  "mfi_pred",  "name", "name_lookup", "new_fit", "plate",  "platemap",
  "plate_list", "png_fit", "pred_class_max", "prefix", "program", "protein",
  "rau", "rau_restricted", "raw_data_filenames", "ref_mfi", "RunColumn",
  "run_column", "sample_id", "sens_spec", "seronegative", "seropositive",
  "slope", "species", "standard_cat", "standard_dil", "standard_type",
  "status_code", "std_sample", "stdcurve", "stds_to_keep", "suffix",
  "to_remove", "type.letter", "upp_asym", "value", "well", "xPONENT",
  "x_ponent"
))
