#' @keywords internal
"_PACKAGE"

## usethis namespace: start
#' @import dplyr
#' @import tidyr
#' @import ggplot2
#' @import stringr
#' @importFrom stats coef na.omit optim predict setNames
#' @importFrom utils read.csv data
#' @importFrom magrittr %>%
## usethis namespace: end
NULL
