% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/readSeroData.R
\name{.check_platform}
\alias{.check_platform}
\title{Check Platform}
\usage{
.check_platform(raw_data, platform, file_name)
}
\arguments{
\item{raw_data}{String with the raw data path.}

\item{platform}{"magpix", "bioplex" or "intelliflex".}

\item{file_name}{String with the raw data filename (for error messaging).}
}
\value{
TRUE: if platform == file format, ERROR message when platform does
not equal file format.
}
\description{
This function checks the platform the user has input and whether it aligns
with the correct format as expected. Will report error if NOT aligned.
}
\examples{
your_raw_data <- system.file("extdata", "example_MAGPIX_plate1.csv", package = "SeroTrackR")
.check_platform(raw_data = your_raw_data, platform = "magpix", file_name = basename(your_raw_data))
}
\author{
Dionne Argyropoulos
}
