% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/renderDetailsList.R
\name{renderDetailsList}
\alias{renderDetailsList}
\title{Create a Fluent UI Table}
\usage{
renderDetailsList(df)
}
\arguments{
\item{df}{Any processed data frame}
}
\value{
A table in the Fluent UI format
}
\description{
This function makes the table in a Fluent UI format.
}
\examples{
# Minimal example using a small data frame.
# This example is safe for CRAN because it runs only if
# shiny.fluent and htmltools are installed.

if (requireNamespace("shiny.fluent", quietly = TRUE) &&
    requireNamespace("htmltools", quietly = TRUE)) {

  # Tiny example data frame
  example_df <- data.frame(
    Sample = c("A", "B"),
    Value = c(10, 20),
    stringsAsFactors = FALSE
  )

  # Render Fluent UI DetailsList
  renderDetailsList(example_df)
}
}
\author{
Dionne Argyropoulos
}
