% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plotRAU.R
\name{plotRAU}
\alias{plotRAU}
\title{Relative Antibody Unit (RAU) Box Plots}
\usage{
plotRAU(mfi_to_rau_output, location)
}
\arguments{
\item{mfi_to_rau_output}{Output from `MFItoRAU()` or `MFItoRAU_Adj()`
.}

\item{location}{"PNG" or "ETH".}
}
\value{
Box plots with RAU values for each protein (ggplot).
}
\description{
Boxplot of the RAU values.
}
\examples{
\donttest{

# Step 0: Load example raw data
your_raw_data <- c(
  system.file("extdata", "example_MAGPIX_plate1.csv", package = "SeroTrackR"),
  system.file("extdata", "example_MAGPIX_plate2.csv", package = "SeroTrackR")
)
your_plate_layout <- system.file(
  "extdata",
  "example_platelayout_1.xlsx",
  package = "SeroTrackR"
)

# Step 1: Read serology data and plate layout
sero_data  <- readSeroData(your_raw_data,"magpix")
plate_list <- readPlateLayout(your_plate_layout, sero_data)

# Step 2: Process counts and perform quality control
qc_results <- runQC(sero_data, plate_list)

# Step 3: Convert MFI to RAU using ETH beads
mfi_to_rau <- MFItoRAU_Adj(
  sero_data   = sero_data,
  plate_list  = plate_list,
  qc_results  = qc_results
)

# Step 4: Plot RAU values
plotRAU(mfi_to_rau, "ETH")
}
}
\author{
Dionne Argyropoulos
}
